#!/usr/bin/python2.7
#
# Univention Management Console
#  Managing ethernet interfaces for agorum core
#
# Copyright 2012 Univention GmbH
#
# http://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

import os.path
import json
import subprocess

from univention.management.console.modules import Base, UMC_CommandError
from univention.management.console.modules.decorators import simple_response
from univention.management.console.log import MODULE

from univention.lib.i18n import Translation

_ = Translation( 'univention-management-console-module-agorum' ).translate

SETUP_SCRIPT = '/opt/agorum/agorumcore/scripts/setup_network.sh'

class Instance( Base ):
	def init( self ):
		# this initialization method is called when the
		# module process is started and the configuration from the
		# UMC server is completed
		pass

	@simple_response
	def all_networks(self):
		"""id=Wert, label=Text..."""
		if not os.path.exists(SETUP_SCRIPT):
			raise UMC_CommandError(_('The setup script does not exist. This probably means that agorum was not installed properly. A common problem is insufficient memory. The minimum system requirement is 2 GB RAM. The installation will continue if the hardware gets upgraded.'))
		jsonData = subprocess.Popen(["/bin/sh", "-c", SETUP_SCRIPT + " listjson"], stdout=subprocess.PIPE).communicate()[0]
		jsonObj = json.loads(jsonData)
		return jsonObj

	@simple_response
	def apply(self, nics, ip, netmask, isVirtual=False):
		"""UCSNetworkHelper (list|set|listjson|setjson) [interface=eth0] [asvirtual=true/false] [ip] [subnetmask=255.255.255.0]"""
		sVirtual = "false"
		sIp = ""
		sNetmask = ""

		if isVirtual:
			sVirtual = "true"
			sIp = " \""+ip+"\""
			sNetmask = " \""+netmask+"\""

		command = SETUP_SCRIPT + " setjson \""+nics+"\" "+sVirtual+sIp+sNetmask
		MODULE.warn("calling: " + command) 
		jsonData = subprocess.Popen(["/bin/sh", "-c", command], stdout=subprocess.PIPE).communicate()[0]
		MODULE.warn( "calling: finished") 
		jsonObj = json.loads(jsonData)
		return jsonObj

