/*
 * Copyright 2012 Univention GmbH
 *
 * http://www.univention.de/
 *
 * All rights reserved.
 *
 * The source code of this program is made available
 * under the terms of the GNU Affero General Public License version 3
 * (GNU AGPL V3) as published by the Free Software Foundation.
 *
 * Binary versions of this program provided by Univention to you as
 * well as other copyrighted, protected or trademarked materials like
 * Logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and Univention and not subject to the GNU AGPL V3.
 *
 * In the case you use this program under the terms of the GNU AGPL V3,
 * the program is provided in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public
 * License with the Debian GNU/Linux or Univention distribution in file
 * /usr/share/common-licenses/AGPL-3; if not, see
 * <http://www.gnu.org/licenses/>.
 */
/*global define console*/

define([
	"dojo/_base/declare",
	"dojo/_base/lang",
	"dojo/_base/array",
	"dojo/topic",
	"umc/dialog",
	"umc/widgets/Module",
	"umc/widgets/Page",
	"umc/widgets/ExpandingTitlePane",
	"umc/widgets/Form",
	"umc/widgets/ComboBox",
	"umc/widgets/CheckBox",
	"umc/widgets/TextBox",
	"umc/i18n!umc/modules/agorum"
], function(declare, lang, array, topic, dialog, Module, Page, ExpandingTitlePane, Form, ComboBox, CheckBox, TextBox, _) {
	return declare("umc.modules.agorum", [ Module ], {
		// summary:
		//		Template module to ease the UMC module development.
		// description:
		//		This module is a template module in order to aid the development of
		//		new modules for Univention Management Console.

		postMixInProperties: function() {
			// is called after all inherited properties/methods have been mixed
			// into the object (originates from dijit._Widget)

			// it is important to call the parent's postMixInProperties() method
			this.inherited(arguments);
		},

		buildRendering: function() {
			// is called after all DOM nodes have been setup
			// (originates from dijit._Widget)

			// it is important to call the parent's buildRendering() method
			this.inherited(arguments);

			// start the standby animation in order prevent any interaction before the
			// form values are loaded
			this.standby(true);

			// render the page containing search form and grid
			this.renderPage();
		},

		renderPage: function() {
			// ExpandingTitlePane is an extension of dijit.layout.BorderContainer
			var titlePane = new ExpandingTitlePane({
				title: _('Setup network interface for agorum core DMS Network Drive')
			});

			//
			// form
			//

			// add remaining elements of the search form
			var widgets = [
				{
					type: ComboBox,
					name: 'nics',
					label: _('Network interface to use'),
					dynamicValues: 'agorum/all_networks'
				}, {
					type: CheckBox,
					name: 'isVirtual',
					label: _('Create virtual network interface')
				}, {
					type: TextBox,
					name: 'ip',
					label: _('IP address for virtual network interface'),
					value: '',
					disabled: true
				}, {
					type: TextBox,
					name: 'netmask',
					label: _('Netmask for virtual network interface'),
					value: '255.255.255.0',
					disabled: true
				}
			];

			// the layout is an 2D array that defines the organization of the form elements...
			// here we arrange the form elements in one row and add the 'submit' button
			var layout = [
				'nics',
				'isVirtual',
				'ip',
				'netmask'
			];

			// generate the form
			this._form = new Form({
				// property that defines the widget's position in a dijit.layout.BorderContainer
				region: 'top',
				widgets: widgets,
				layout: layout,
				scrollable: true
			});
			this._form.getWidget('isVirtual').watch('value', lang.hitch(this, function(attr, oldVal, newVal) {
				this._form.getWidget('ip').set('disabled', !newVal);
				this._form.getWidget('netmask').set('disabled', !newVal);
			}));

			// turn off the standby animation as soon as all form values have been loaded
			this._form.ready().then(lang.hitch(this, function() {
				this.standby(false);
			}));
			this._form.on('submit', lang.hitch(this, 'onSubmit'));

			// add form to the title pane
			titlePane.addChild(this._form);

			// submit changes
			var buttons = [ {
				name: 'submit',
				label: _('Apply changes'),
				'default': true,
				callback: lang.hitch(this, 'onSubmit')
			}];

			this._page = new Page({
				headerText: this.description,
				helpText: _('agorum core needs a unique network interface for the dms-drive to work (otherwise there would be conflict between agorum core and Samba). Therefore you are able to configure a network card here. Either you specify an existing interface (e.g. eht1), that you have configured before, or you take your default interface and let this script create a second virtual interface on the selected interface. If you choose the virtual interface, you have to define an IP address, that will we applied to this virtual interface. The agorum core DMS network share is then reachable through the ip of the selected/created interface, Samba will be available on all other interfaces.'),
				footerButtons: buttons
			});

			this.addChild(this._page);
			this._page.addChild(titlePane);
			
			/*
			this._form.getWidget('nics').store.fetch({
				onItem: function(item) {
					alert("a");
					//console.log(store.getValue(item, 'id'));
				}
			});
			*/
			
			this.initNics();
			//this._form.getWidget('nics').store.on("Complete", function() { alert("loaded"); });
		},

		//set the default agorum nic
		initNics: function() {
			var nics = this._form.getWidget('nics');
			nics.ready().then(function() {
				var arr = nics.store._getItemsArray();
				array.forEach(arr, function(item) {
					if (item.agorumIp && item.agorumIp[0] === true) {
						nics.set('value', item.id);
					}
				});
			});
		},
		
		onSubmit: function() {
			var values = this._form.gatherFormValues();
			var isVirt = values.isVirtual;
			var theIp = values.ip;

			if (!isVirt || (theIp && theIp.length > 0)) {
				dialog.confirm(_('Network settings will be applied, this could take a while (Attention Samba and agorum core will be restarted)...'), [ {
					label: _('Confirm'),
					name: 'confirm'
				}, {
					label: _('Cancel'),
					name: 'cancel',
					'default': true
				} ]).then(lang.hitch(this, function(confirm_name) {
					if (confirm_name == 'confirm') {
						this.standby(true);
						this.umcpCommand('agorum/apply', values).then(
							lang.hitch(this, function(response) {
								this.standby(false);
								if (response.result.errorCode === 0) {
									dialog.alert(_('Network interface has been configured'));
								} else {
									dialog.alert(_('Error:') + ' ' + _(response.result.message));
								}
							}),
							lang.hitch(this, function() {
								this.standby(false);
							})
						);
					}
				}));
			} else {
				dialog.alert(_('Please enter an IP address'));
			}
		}
	});
});
